pub trait SortedInsertArcRwLock<T: Ord>: SortedInsertArcRwLockByKey<T> {
// Provided methods
fn sorted_insert_asc(&mut self, element: Arc<RwLock<T>>) -> usize { ... }
fn sorted_insert_desc(&mut self, element: Arc<RwLock<T>>) -> usize { ... }
}Available on crate feature
std only.Provided Methods
Sourcefn sorted_insert_asc(&mut self, element: Arc<RwLock<T>>) -> usize
fn sorted_insert_asc(&mut self, element: Arc<RwLock<T>>) -> usize
Insert an element to this sorted collection in ascending order and return the inserted index. Use linear search to find the index where a matching element could be inserted.
Panics
This function will panic if any involved lock is poisoned.
Sourcefn sorted_insert_desc(&mut self, element: Arc<RwLock<T>>) -> usize
fn sorted_insert_desc(&mut self, element: Arc<RwLock<T>>) -> usize
Insert an element to this sorted collection in descending order and return the inserted index. Use linear search to find the index where a matching element could be inserted.
Panics
This function will panic if any involved lock is poisoned.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".