SortedInsertBinaryArcMutex

Trait SortedInsertBinaryArcMutex 

pub trait SortedInsertBinaryArcMutex<T: Ord>: SortedInsertBinaryArcMutexByKey<T> {
    // Provided methods
    fn sorted_insert_asc_binary(&mut self, element: Arc<Mutex<T>>) -> usize { ... }
    fn sorted_insert_desc_binary(&mut self, element: Arc<Mutex<T>>) -> usize { ... }
}
Available on crate feature std only.

Provided Methods

fn sorted_insert_asc_binary(&mut self, element: Arc<Mutex<T>>) -> usize

Insert an element to this sorted collection in ascending order and return the inserted index. Use binary search to find the index where a matching element could be inserted.

Panics

This function will panic if any involved lock is poisoned.

fn sorted_insert_desc_binary(&mut self, element: Arc<Mutex<T>>) -> usize

Insert an element to this sorted collection in descending order and return the inserted index. Use binary search to find the index where a matching element could be inserted.

Panics

This function will panic if any involved lock is poisoned.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: Ord> SortedInsertBinaryArcMutex<T> for Vec<Arc<Mutex<T>>>

Source

impl<T: Ord> SortedInsertBinaryArcMutex<T> for VecDeque<Arc<Mutex<T>>>

Implementors