pub trait SortedInsertBinaryArcRwLockBy<T>: SortedInsertArcRwLockBy<T> {
// Provided method
fn sorted_insert_binary_by<F: FnMut(&Arc<RwLock<T>>, &T) -> Ordering>(
&mut self,
element: Arc<RwLock<T>>,
f: F,
) -> usize { ... }
}Available on crate feature
std only.Provided Methods
Sourcefn sorted_insert_binary_by<F: FnMut(&Arc<RwLock<T>>, &T) -> Ordering>(
&mut self,
element: Arc<RwLock<T>>,
f: F,
) -> usize
fn sorted_insert_binary_by<F: FnMut(&Arc<RwLock<T>>, &T) -> Ordering>( &mut self, element: Arc<RwLock<T>>, f: F, ) -> usize
Insert an element to this sorted collection by a specific comparator and return the inserted index. Use binary search to find the index where a matching element could be inserted.
Panics
This function will panic if any involved lock is poisoned.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".