pub trait SortedInsertBinaryByKey<T>: SortedInsertBinaryBy<T> {
// Provided methods
fn sorted_insert_binary_asc_by_key<A: Ord, F: FnMut(&T) -> &A>(
&mut self,
element: T,
f: F,
) -> usize { ... }
fn sorted_insert_binary_desc_by_key<A: Ord, F: FnMut(&T) -> &A>(
&mut self,
element: T,
f: F,
) -> usize { ... }
}Provided Methods
Sourcefn sorted_insert_binary_asc_by_key<A: Ord, F: FnMut(&T) -> &A>(
&mut self,
element: T,
f: F,
) -> usize
fn sorted_insert_binary_asc_by_key<A: Ord, F: FnMut(&T) -> &A>( &mut self, element: T, f: F, ) -> usize
Insert elements to this sorted collection in ascending order by a specific key and return the inserted index. Use binary search to find the index where a matching element could be inserted.
Sourcefn sorted_insert_binary_desc_by_key<A: Ord, F: FnMut(&T) -> &A>(
&mut self,
element: T,
f: F,
) -> usize
fn sorted_insert_binary_desc_by_key<A: Ord, F: FnMut(&T) -> &A>( &mut self, element: T, f: F, ) -> usize
Insert elements to this sorted collection in descending order by a specific key and return the inserted index. Use binary search to find the index where a matching element could be inserted.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".